==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/et_EE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Sinuga jagatud",
    "Nothing shared with you yet" : "Sinuga pole veel midagi jagatud",
    "Files and folders others share with you will show up here" : "Siin näidatakse faile ja kaustasid, mida teised on sulle jaganud",
    "Shared with others" : "Teistega jagatud",
    "Nothing shared yet" : "Midagi pole veel jagatud",
    "Files and folders you share will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa oled teistega jaganud",
    "Shared by link" : "Jagatud lingiga",
    "No shared links" : "Jagatud linke pole",
    "Files and folders you share by link will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa jagad lingiga",
    "Shares" : "Jagamisi",
    "Restore" : "Taasta",
    "error" : "viga",
    "Move or copy" : "Liiguta või kopeeri",
    "Download" : "Lae alla",
    "Delete" : "Kustuta",
    "You can upload into this folder" : "Sa saad sellesse kausta faile üles laadida",
    "No compatible server found at {remote}" : "Aadressil {remote} ei leitud ühilduvat serverit",
    "Invalid server URL" : "Vigane serveri URL",
    "Failed to add the public link to your Nextcloud" : "Avaliku lingi lisamine sinu Nextcloudi ebaõnnestus",
    "No expiration date set" : "Aegumise kuupäeva pole määratud",
    "Shared by" : "Jagas",
    "File shares" : "Jagatud failid",
    "Downloaded via public link" : "Alla laetud avalikult lingilt",
    "Downloaded by {email}" : "Alla laetud {email} poolt",
    "{file} downloaded via public link" : "{file} laeti alla avaliku lingi kaudu",
    "{email} downloaded {file}" : "{email} laadis {file} alla",
    "Shared with group {group}" : "Jagatud grupiga {group}",
    "Removed share for group {group}" : "Eemaldas jagamise grupiga {group}",
    "{actor} shared with group {group}" : "{actor} jagas grupiga {group}",
    "{actor} removed share for group {group}" : "{actor} eemaldas jagamise grupiga {group}",
    "You shared {file} with group {group}" : "Sa jagasid faili {file} grupiga {group}",
    "You removed group {group} from {file}" : "Sa eemaldasid grupi {group} faili {file} jagamisest",
    "{actor} shared {file} with group {group}" : "{actor} jagas faili {file} grupiga {group}",
    "{actor} removed group {group} from {file}" : "{actor} eemaldas grupi {group} faili {file} jagamisest",
    "Shared as public link" : "Jaga avaliku lingina",
    "Removed public link" : "Avalik link on eemaldatud",
    "Public link expired" : "Avalik link aegus",
    "{actor} shared as public link" : "{actor} jagas avaliku lingina",
    "{actor} removed public link" : "{actor} eemaldas avaliku lingi",
    "Public link of {actor} expired" : "{actor} avalik link aegus",
    "You shared {file} as public link" : "Sa jagasid {file} avaliku lingina",
    "You removed public link for {file}" : "Sa eemaldasid {file} avaliku lingi",
    "Public link expired for {file}" : "{file} avalik link aegus",
    "{actor} shared {file} as public link" : "{actor} jagas {file} avaliku lingina",
    "{actor} removed public link for {file}" : "{actor} eemaldas {file} avaliku lingi",
    "Public link of {actor} for {file} expired" : " {actor} faili {file} avalik link aegus",
    "{user} accepted the remote share" : "{user} aksepteeris kaugjagamise",
    "{user} declined the remote share" : "{user} keeldus kaugjagamisest",
    "You received a new remote share {file} from {user}" : "Sa said uue kaugjagatud faili {file} kasutajalt {user}",
    "{user} accepted the remote share of {file}" : "{user} aksepteeris faili {file} kaugjagamise",
    "{user} declined the remote share of {file}" : "{user} keeldus faili {file} kaugjagamisest",
    "{user} unshared {file} from you" : "{user} lõpetas sinuga faili {file} jagamise",
    "Shared with {user}" : "Jagatud kasutajale {user}",
    "Removed share for {user}" : "Eemaldas jagamise kasutajaga {user}",
    "{actor} shared with {user}" : "{actor} jagas kasutajaga {user}",
    "{actor} removed share for {user}" : "{actor} eemaldas jagamise kasutajaga {user}",
    "Shared by {actor}" : "Jagatud kasutajalt {actor}",
    "{actor} removed share" : "{actor} eemaldas jagamise",
    "You shared {file} with {user}" : "Sa jagasid {file} kasutajaga {user}",
    "You removed {user} from {file}" : "Sa eemaldasid faili {file} jagamise kasutajaga {user} ",
    "{actor} shared {file} with {user}" : "{actor} jagas {file} kasutajaga {user}",
    "{actor} removed {user} from {file}" : "{actor} eemaldas {user} jagamise faililt {file}",
    "{actor} shared {file} with you" : "{actor} jagas sinuga {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Fail või kaust mis on jagatud e-posti või avaliku lingiga  <strong>laeti alla</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Fail või kaust jagati <strong>teisest serverist</strong>",
    "A file or folder has been <strong>shared</strong>" : "Fail või kataloog on <strong>jagatud</strong>",
    "Wrong share ID, share doesn't exist" : "Vale jagamise ID, sellist jagamist ei eksisteeri",
    "Could not delete share" : "Ei saanud jagamist eemaldada",
    "Please specify a file or folder path" : "Palun määra faili või kausta rada",
    "Wrong path, file/folder doesn't exist" : "Vale rada, faili/kausta ei leitud",
    "Could not create share" : "Ei saanud jagamist luua",
    "invalid permissions" : "valed õigused",
    "Please specify a valid user" : "Palun määra kehtiv kasutaja",
    "Group sharing is disabled by the administrator" : "Grupiga jagamine on administraatori poolt keelatud",
    "Please specify a valid group" : "Palun määra kehtiv grupp",
    "Public link sharing is disabled by the administrator" : "Avaliku lingiga jagamine on administraatori poolt keelatud",
    "Public upload disabled by the administrator" : "Avalik üleslaadimine on administraatori poolt keelatud",
    "Public upload is only possible for publicly shared folders" : "Avalik üleslaadminie on võimalik ainult avalikult jagatud kaustades",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Sa ei saa jagada Ringi kui see rakendus pole lubatud",
    "Please specify a valid circle" : "Palun määra kehtiv ring",
    "Unknown share type" : "Tundmatu jagamise tüüp",
    "Not a directory" : "Ei ole kaust",
    "Could not lock path" : "Ei saanud rada lukustada",
    "Wrong or no update parameter given" : "Antud vale või aegunud parameeter",
    "Can't change permissions for public share links" : "Avalikult jagatud linkide õigusi muuta ei saa",
    "shared by %s" : "jagas %s",
    "Direct link" : "Otsene link",
    "Add to your Nextcloud" : "Lisa oma Nextcloudi",
    "Share API is disabled" : "Jagamise API on keelatud",
    "Accept" : "Nõustu",
    "Sharing" : "Jagamine",
    "Allow editing" : "Luba muutmine",
    "Allow resharing" : "Luba edasijagamine",
    "Set expiration date" : "Määra aegumise kuupäev",
    "Unshare" : "Lõpeta jagamine",
    "group" : "grupp",
    "remote" : "kaug",
    "guest" : "külaline",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Cancel" : "Loobu",
    "Read only" : "kirjutuskaitstud",
    "Allow upload and editing" : "Luba üleslaadimine ja muutmine",
    "File drop (upload only)" : "Faili lohistamine (ainult üleslaadimine)",
    "Password protect" : "Parooliga kaitsmine",
    "Share link" : "Jaga link",
    "Resharing is not allowed" : "Edasijagamine pole lubatud",
    "Shared" : "Jagatud",
    "Share" : "Jaga",
    "Shared with" : "Jagatud",
    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja grupiga {group} {owner} poolt",
    "Shared with you by {owner}" : "Jagatud sinuga {owner} poolt",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Name" : "Nimi",
    "Share time" : "Jagamise aeg",
    "Expiration date" : "Aegumise kuupäev",
    "Sorry, this link doesn’t seem to work anymore." : "Vabandust, see link ei tundu enam toimivat.",
    "Reasons might be:" : "Põhjused võivad olla:",
    "the item was removed" : "üksus on eemaldatud",
    "the link expired" : "link on aegunud",
    "sharing is disabled" : "jagamine on peatatud",
    "For more info, please ask the person who sent this link." : "Täpsema info saamiseks palun pöördu lingi saatnud isiku poole.",
    "Share note" : "Jaga märget",
    "Download %s" : "Laadi alla %s",
    "Upload files to %s" : "Laadi failid %s",
    "Select or drop files" : "Vali või lohista failid",
    "Uploaded files:" : "Üleslaetud failid:",
    "could not delete share" : "ei saanud jagamist eemaldada",
    "Uploading files…" : "Failide üleslaadimine…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/et_EE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Sinuga jagatud",
    "Nothing shared with you yet" : "Sinuga pole veel midagi jagatud",
    "Files and folders others share with you will show up here" : "Siin näidatakse faile ja kaustasid, mida teised on sulle jaganud",
    "Shared with others" : "Teistega jagatud",
    "Nothing shared yet" : "Midagi pole veel jagatud",
    "Files and folders you share will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa oled teistega jaganud",
    "Shared by link" : "Jagatud lingiga",
    "No shared links" : "Jagatud linke pole",
    "Files and folders you share by link will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa jagad lingiga",
    "Deleted shares" : "Kustutatud jagamised",
    "No deleted shares" : "Kustutatud jagamisi pole",
    "Shares you deleted will show up here" : "Sinu kustutatud jagamisi näidatakse siin",
    "Pending shares" : "Ootel jagamised",
    "No pending shares" : "Ootel jagamisi pole",
    "Shares" : "Jagamisi",
    "No shares" : "Jagamisi pole",
    "Shares will show up here" : "Jagamisi näidatakse siin",
    "Restore" : "Taasta",
    "Restore share" : "Taasta jagamine",
    "Something happened. Unable to restore the share." : "Midagi juhtus. Ei saa jagamist taastada.",
    "Accept share" : "Võta jagamine vastu",
    "Reject share" : "Lükka jagamine tagasi",
    "Waiting…" : "Ootan...",
    "error" : "viga",
    "finished" : "lõpetatud",
    "This will stop your current uploads." : "See peatab praegused üleslaadimised.",
    "Move or copy" : "Liiguta või kopeeri",
    "Download" : "Lae alla",
    "Delete" : "Kustuta",
    "You can upload into this folder" : "Sa saad sellesse kausta faile üles laadida",
    "Terms of service" : "Kasutustingimused",
    "No compatible server found at {remote}" : "Aadressil {remote} ei leitud ühilduvat serverit",
    "Invalid server URL" : "Vigane serveri URL",
    "Failed to add the public link to your Nextcloud" : "Avaliku lingi lisamine sinu Nextcloudi ebaõnnestus",
    "No expiration date set" : "Aegumise kuupäeva pole määratud",
    "Shared by" : "Jagas",
    "File shares" : "Jagatud failid",
    "Downloaded via public link" : "Alla laetud avalikult lingilt",
    "Downloaded by {email}" : "Alla laetud {email} poolt",
    "{file} downloaded via public link" : "{file} laeti alla avaliku lingi kaudu",
    "{email} downloaded {file}" : "{email} laadis {file} alla",
    "Shared with group {group}" : "Jagatud grupiga {group}",
    "Removed share for group {group}" : "Eemaldas jagamise grupiga {group}",
    "{actor} shared with group {group}" : "{actor} jagas grupiga {group}",
    "{actor} removed share for group {group}" : "{actor} eemaldas jagamise grupiga {group}",
    "You shared {file} with group {group}" : "Sa jagasid faili {file} grupiga {group}",
    "You removed group {group} from {file}" : "Sa eemaldasid grupi {group} faili {file} jagamisest",
    "{actor} shared {file} with group {group}" : "{actor} jagas faili {file} grupiga {group}",
    "{actor} removed group {group} from {file}" : "{actor} eemaldas grupi {group} faili {file} jagamisest",
    "Shared as public link" : "Jaga avaliku lingina",
    "Removed public link" : "Avalik link on eemaldatud",
    "Public link expired" : "Avalik link aegus",
    "{actor} shared as public link" : "{actor} jagas avaliku lingina",
    "{actor} removed public link" : "{actor} eemaldas avaliku lingi",
    "Public link of {actor} expired" : "{actor} avalik link aegus",
    "You shared {file} as public link" : "Sa jagasid {file} avaliku lingina",
    "You removed public link for {file}" : "Sa eemaldasid {file} avaliku lingi",
    "Public link expired for {file}" : "{file} avalik link aegus",
    "{actor} shared {file} as public link" : "{actor} jagas {file} avaliku lingina",
    "{actor} removed public link for {file}" : "{actor} eemaldas {file} avaliku lingi",
    "Public link of {actor} for {file} expired" : " {actor} faili {file} avalik link aegus",
    "{user} accepted the remote share" : "{user} aksepteeris kaugjagamise",
    "{user} declined the remote share" : "{user} keeldus kaugjagamisest",
    "You received a new remote share {file} from {user}" : "Sa said uue kaugjagatud faili {file} kasutajalt {user}",
    "{user} accepted the remote share of {file}" : "{user} aksepteeris faili {file} kaugjagamise",
    "{user} declined the remote share of {file}" : "{user} keeldus faili {file} kaugjagamisest",
    "{user} unshared {file} from you" : "{user} lõpetas sinuga faili {file} jagamise",
    "Shared with {user}" : "Jagatud kasutajale {user}",
    "Removed share for {user}" : "Eemaldas jagamise kasutajaga {user}",
    "You removed yourself" : "Sa eemaldasid iseenda",
    "{actor} removed themselves" : "{actor} eemaldas enda",
    "{actor} shared with {user}" : "{actor} jagas kasutajaga {user}",
    "{actor} removed share for {user}" : "{actor} eemaldas jagamise kasutajaga {user}",
    "Shared by {actor}" : "Jagatud kasutajalt {actor}",
    "{actor} removed share" : "{actor} eemaldas jagamise",
    "Share expired" : "Jagamine aegus",
    "You shared {file} with {user}" : "Sa jagasid {file} kasutajaga {user}",
    "You removed {user} from {file}" : "Sa eemaldasid faili {file} jagamise kasutajaga {user} ",
    "{actor} shared {file} with {user}" : "{actor} jagas {file} kasutajaga {user}",
    "{actor} removed {user} from {file}" : "{actor} eemaldas {user} jagamise faililt {file}",
    "{actor} shared {file} with you" : "{actor} jagas sinuga {file}",
    "{actor} removed you from the share named {file}" : "{actor} lõpetas sinuga {file} jagamise",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Fail või kaust mis on jagatud e-posti või avaliku lingiga  <strong>laeti alla</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Fail või kaust jagati <strong>teisest serverist</strong>",
    "Files" : "Failid",
    "A file or folder has been <strong>shared</strong>" : "Fail või kataloog on <strong>jagatud</strong>",
    "Shared link" : "Jagatud link",
    "Wrong share ID, share doesn't exist" : "Vale jagamise ID, sellist jagamist ei eksisteeri",
    "Could not delete share" : "Ei saanud jagamist eemaldada",
    "Please specify a file or folder path" : "Palun määra faili või kausta rada",
    "Wrong path, file/folder doesn't exist" : "Vale rada, faili/kausta ei leitud",
    "Could not create share" : "Ei saanud jagamist luua",
    "invalid permissions" : "valed õigused",
    "Please specify a valid user" : "Palun määra kehtiv kasutaja",
    "Group sharing is disabled by the administrator" : "Grupiga jagamine on administraatori poolt keelatud",
    "Please specify a valid group" : "Palun määra kehtiv grupp",
    "Public link sharing is disabled by the administrator" : "Avaliku lingiga jagamine on administraatori poolt keelatud",
    "Public upload disabled by the administrator" : "Avalik üleslaadimine on administraatori poolt keelatud",
    "Public upload is only possible for publicly shared folders" : "Avalik üleslaadminie on võimalik ainult avalikult jagatud kaustades",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Sa ei saa jagada Ringi kui see rakendus pole lubatud",
    "Please specify a valid circle" : "Palun määra kehtiv ring",
    "Unknown share type" : "Tundmatu jagamise tüüp",
    "Not a directory" : "Ei ole kaust",
    "Could not lock path" : "Ei saanud rada lukustada",
    "Wrong or no update parameter given" : "Antud vale või aegunud parameeter",
    "Can't change permissions for public share links" : "Avalikult jagatud linkide õigusi muuta ei saa",
    "shared by %s" : "jagas %s",
    "Download all files" : "Lae kõik failid alla",
    "Direct link" : "Otsene link",
    "Add to your Nextcloud" : "Lisa oma Nextcloudi",
    "Share API is disabled" : "Jagamise API on keelatud",
    "File sharing" : "Faide jagamine",
    "Share will expire tomorrow" : "Jagamine aegub homme",
    "One or more of your shares will expire tomorrow" : "Sinu üks või enam jagamist aegub homme",
    "Accept" : "Nõustu",
    "Reject" : "Keeldu",
    "Sharing" : "Jagamine",
    "Allow editing" : "Luba muutmine",
    "Allow creating" : "Luba loomine",
    "Allow deleting" : "Luba kustutamine",
    "Allow resharing" : "Luba edasijagamine",
    "Expiration date enforced" : "Aegumise kuupäev jõustatud",
    "Set expiration date" : "Määra aegumise kuupäev",
    "Enter a date" : "Sisesta kuupäev",
    "Note to recipient" : "Märge saajale",
    "Unshare" : "Lõpeta jagamine",
    "group" : "grupp",
    "conversation" : "vestlus",
    "remote" : "kaug",
    "remote group" : "Kauggrupp",
    "guest" : "külaline",
    "Internal link" : "Sisemine link",
    "Link copied" : "Link kopeeritud",
    "Cannot copy, please copy the link manually" : "Ei saa kopeerida, palun kopeeri link käsitsi",
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Password protection (enforced)" : "Paroolikaitse (jõustatud)",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Expiration date (enforced)" : "Aegumise kuupäev (jõustatud)",
    "Cancel" : "Loobu",
    "Read only" : "kirjutuskaitstud",
    "Allow upload and editing" : "Luba üleslaadimine ja muutmine",
    "File drop (upload only)" : "Faili lohistamine (ainult üleslaadimine)",
    "Password protect" : "Parooliga kaitsmine",
    "Share link" : "Jaga link",
    "Resharing is not allowed" : "Edasijagamine pole lubatud",
    "Searching …" : "Otsin ...",
    "Expires {relativetime}" : "Aegub {relativetime}",
    "this share just expired." : "see jagamine aegus äsja",
    "Shared" : "Jagatud",
    "Share" : "Jaga",
    "Shared with" : "Jagatud",
    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja grupiga {group} {owner} poolt",
    "Shared with you by {owner}" : "Jagatud sinuga {owner} poolt",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Name" : "Nimi",
    "Share time" : "Jagamise aeg",
    "Expiration date" : "Aegumise kuupäev",
    "Sorry, this link doesn’t seem to work anymore." : "Vabandust, see link ei tundu enam toimivat.",
    "Reasons might be:" : "Põhjused võivad olla:",
    "the item was removed" : "üksus on eemaldatud",
    "the link expired" : "link on aegunud",
    "sharing is disabled" : "jagamine on peatatud",
    "For more info, please ask the person who sent this link." : "Täpsema info saamiseks palun pöördu lingi saatnud isiku poole.",
    "Share note" : "Jaga märget",
    "Download %s" : "Laadi alla %s",
    "Upload files to %s" : "Laadi failid %s",
    "Note" : "Märge",
    "Select or drop files" : "Vali või lohista failid",
    "Uploaded files:" : "Üleslaetud failid:",
    "Name …" : "Nimi ...",
    "Uploading files…" : "Failide üleslaadimine…"
},
"nplurals=2; plural=(n != 1);");
